Encrypt

Enum Encrypt 

pub enum Encrypt<'a, R: Read + Seek = File> {
    Dh([u8; 32], &'a Vec<[u8; 32]>, Option<[u8; 32]>),
    Hmac([u8; 32], [u8; 32], usize),
    Session([u8; 32], bool),
    Kem(KemKeyReader<R>),
}
encapsulates the parameters and mode for encryption.

Variants



Dh([u8; 32], &'a Vec<[u8; 32]>, Option<[u8; 32]>)

generates random content key and encrypts for all recipients with their respective Diffie-Hellman shared secret.

Tuple Fields

0: [u8; 32]

sender private key

1: &'a Vec<[u8; 32]>

recipient public keys

2: Option<[u8; 32]>

optional HMAC key



Hmac([u8; 32], [u8; 32], usize)

hashes the second tuple member, with the first tuple member as the HMAC key.

Tuple Fields

0: [u8; 32]

HMAC key

1: [u8; 32]

HMAC value

2: usize

iteration



Session([u8; 32], bool)

uses the key that is passed in without modification.

Tuple Fields

0: [u8; 32]

session key

1: bool

with key gen



Kem(KemKeyReader<R>)

uses key encapsulation to encrypt a copy of the a one-time generated content key for each recipient.

Tuple Fields

0: KemKeyReader<R>

recipient KEM public keys reader