pub enum Encrypt<'a, R: Read + Seek = File> {
Dh([u8; 32], &'a Vec<[u8; 32]>, Option<[u8; 32]>),
Hmac([u8; 32], [u8; 32], usize),
Session([u8; 32], bool),
Kem(KemKeyReader<R>),
}Expand description
encapsulates the parameters and mode for encryption.
Variants
Dh([u8; 32], &'a Vec<[u8; 32]>, Option<[u8; 32]>)
generates random content key and encrypts for all recipients with their respective Diffie-Hellman shared secret.
Tuple Fields
Hmac([u8; 32], [u8; 32], usize)
hashes the second tuple member, with the first tuple member as the HMAC key.
Session([u8; 32], bool)
uses the key that is passed in without modification.
Kem(KemKeyReader<R>)
uses key encapsulation to encrypt a copy of the a one-time generated content key for each recipient.
Tuple Fields

0: KemKeyReader<R>recipient KEM public keys reader