pub struct KemKeyReader<R: Read + Seek> {
pub reader: BufReader<R>,
pub dh_priv_key: Option<[u8; 32]>,
}Expand description
for reading a large volume of Classic McEliece public keys
Fields
reader: BufReader<R>dh_priv_key: Option<[u8; 32]>for Kem + Dh hybrid
Implementations
Sourceimpl<R: Read + Seek> KemKeyReader<R>
impl<R: Read + Seek> KemKeyReader<R>
Sourcepub fn new(source: R) -> Self
pub fn new(source: R) -> Self
public key reader with a buffer size of 261120.
for files that contain only McEliece public keys all in one line.
Sourcepub fn new_dh_hybrid(dh_priv_key: [u8; 32], source: R) -> Self
pub fn new_dh_hybrid(dh_priv_key: [u8; 32], source: R) -> Self
public key reader with a buffer size of 261120 + 32.
for files that contain McEliece public paired with their Diffie-Hellman counterparts (i.e Vec<…[u8; …mc_pub, …dh_pub]>)